============
Installation
============

At the command line::

    $ pip install group-based-policy-ui

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv group-based-policy-ui
    $ pip install group-based-policy-ui